package router

import (
	"github.com/gin-gonic/gin"
	"gitlab.wodcloud.com/smart-operation/so-operation-api/src/common/conf"
	"gitlab.wodcloud.com/smart-operation/so-operation-api/src/controller"
	"gitlab.wodcloud.com/smart-operation/so-operation-api/src/router/middleware/header"
)

// 加载路由
func Load(r *gin.Engine, middleware ...gin.HandlerFunc) {
	r.Use()
	r.Use(gin.Recovery())
	r.Use(header.NoCache)
	r.Use(header.Options)
	r.Use(header.Secure)
	r.Use(header.CopyResponseBody)
	r.Use(middleware...)

	/*gin.DebugPrintRouteFunc = func(httpMethod, absolutePath, handlerName string, nuHandlers int) {
		conf.Logger.Info("routers", zap.String("endpoint", fmt.Sprintf("%v %v %v %v", httpMethod, absolutePath, handlerName, nuHandlers)))
	}*/

	base := r.Group(conf.Options.Prefix)
	{
		base.GET("/health", controller.Health)               // 健康检查
		base.GET("/example", controller.Example)             // 示例
		base.GET("/example/list", controller.GetExampleList) // 示例获取列表
	}

	base.POST("addFile", controller.AddFile) //文件上传

	// 初始化自动化运维路由
	InitAutomatedMaintenRouter(r)
	// 初始化登录路由
	InitSystemLoginRouter(r)
	// 初始化组织相关路由
	InitOrganizationRouter(r)
	// 初始化指标配置路由
	InitMetricConfigRouter(r)
}
